@@ -13,9 +13,9 @@ admin.site.unregister(Group)
 
 @admin.register(User)
 class UserAdmin(admin.ModelAdmin):
-    list_display = ('id', 'username', 'first_name', 'email', 'is_staff', 'is_active', 'date_joined')
+    list_display = ('id', 'username', 'first_name', 'email', 'is_active', 'is_staff', 'is_superuser', 'date_joined')
     search_fields = ('=id', '=username')
-    list_filter = ('is_staff', 'is_active')
+    list_filter = ('is_staff', 'is_active', 'is_superuser')
 
     def has_add_permission(self, request):
         return False
